import { AfterViewInit, Component, ViewChild } from '@angular/core';
import { BryntumSchedulerComponent } from '@bryntum/scheduler-angular';
import { DateHelper,  Field,  Scheduler } from '@bryntum/scheduler/scheduler.lite.umd.js';
import AppEventModel from './lib/AppEventModel';
import { schedulerConfig } from './app.config';

@Component({
    selector    : 'app-root',
    templateUrl : './app.component.html',
    styleUrls   : ['./app.component.scss']
})
export class AppComponent implements AfterViewInit {

    @ViewChild(BryntumSchedulerComponent, { static: true }) schedulerComponent: BryntumSchedulerComponent;

    selectedValue: string = '1';

    additionalResources = [
        { "id": "aa", "name": "Arcady", "age": "27" },
        { "id": "bb", "name": "Dave", "age": "27" },
        { "id": "cc", "name": "Henrik", "age": "27" }
    ];

    additionalEvents: [
        {
            "id"        : 1,
            "resourceId": "aa",
            "name"      : "Meeting #1",
            "desc"      : "Discuss new features",
            "startDate" : "2018-02-07 11:00",
            "endDate"   : "2018-02-07 14:00",
            "eventType" : "Meeting",
            "eventColor": "blue",
            "iconCls"   : "b-fa b-fa-calendar"
          },
          {
            "id"        : 2,
            "resourceId": "bb",
            "name"      : "Meeting #2",
            "desc"      : "Strategy meeting",
            "startDate" : "2018-02-07 12:00",
            "endDate"   : "2018-02-07 15:00",
            "eventType" : "Meeting",
            "eventColor": "blue",
            "iconCls"   : "b-fa b-fa-calendar"
          },
          {
            "id"        : 3,
            "resourceId": "cc",
            "name"      : "Meeting #3",
            "desc"      : "Emerging markets",
            "startDate" : "2018-02-07 13:00",
            "endDate"   : "2018-02-07 16:00",
            "eventType" : "Meeting",
            "eventColor": "blue",
            "iconCls"   : "b-fa b-fa-calendar"
          }
    ]
    schedulerConfig: any = schedulerConfig;
    columns: any[] = [
        {
            text: '',
            field: 'id',
            hidden: true
        }
    ];

    // application properties
    scheduler: Scheduler;
    selectedEventName  = '';
    pickerDate = new Date(2018, 1, 7);
    barMargin = 5;

    ngAfterViewInit(): void {
        this.scheduler = this.schedulerComponent.instance;
        this.scheduler.columns.add(this.schedulerConfig.columns);
    }

    myFunction() {
        const columns: any[] = this.schedulerConfig.columns;
        if (this.selectedValue == '1') {
            columns[0].hidden = false;
            columns[1].hidden = true;
            columns[2].hidden = true;
            this.scheduler.columns.removeAll();
            this.scheduler.columns.add(columns);
        }
        if (this.selectedValue == '2') {
            columns[0].hidden = false;
            columns[1].hidden = false;
            columns[2].hidden = true;
            this.scheduler.columns.removeAll();
            this.scheduler.columns.add(columns);
        }
        if (this.selectedValue == '3') {
            columns[0].hidden = false;
            columns[1].hidden = false;
            columns[2].hidden = false;
            this.scheduler.resourceStore.removeAll();
            this.scheduler.eventStore.removeAll();
            this.scheduler.columns.removeAll();
            this.scheduler.columns.add(columns);
            this.scheduler.resourceStore.add(this.additionalResources);
            this.scheduler.eventStore.add(this.additionalEvents);
        }
    }
    // add event button click handled here
    onAddEventClick(): void {
        const { scheduler } = this;

        const event = new AppEventModel({
            resourceId   : scheduler.resourceStore.first.id,
            startDate    : scheduler.startDate,
            duration     : 2,
            durationUnit : 'h',
            name         : 'Meet CEO',
            desc         : 'Discuss project',
            eventType    : 'Meeting',
            eventColor   : 'red'
        });

        scheduler.editEvent(event);
    }

    //remove event button click handled here
    onRemoveEventClick(): void {
        const { scheduler } = this;
        scheduler.eventStore.remove(scheduler.selectedEvents);
    }

    onBarMarginChange({ value }): void {
        this.barMargin = value;
    }

    onEventSelectionChange(): void {
        if (this.scheduler.selectedEvents.length > 0) {
            this.selectedEventName = this.scheduler.selectedEvents[0].name;
        }
        else {
            this.selectedEventName = '';
        }
    }

    onReleaseEvent(): void {
        this.selectedEventName = '';
    }

    onDatePickerChange({ value }) : void {
        this.scheduler.setTimeSpan(
            DateHelper.add(value, 8, 'hour'),
            DateHelper.add(value, 18, 'hour')
        );
    }
}
